Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4243)

Unified Diff: chrome/browser/ui/libgtkui/gconf_listener.h

Issue 2610883004: Gtk3: Rename Gtk2UI and Get[FB]GColor (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/themes/theme_service.cc ('k') | chrome/browser/ui/libgtkui/gconf_listener.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/libgtkui/gconf_listener.h
diff --git a/chrome/browser/ui/libgtkui/gconf_listener.h b/chrome/browser/ui/libgtkui/gconf_listener.h
index b57ceced3c33d1fe50d50e8e7d15598fbd1514c3..25b60ecca8bc3cf09c8b143441bf17ac96c30cbf 100644
--- a/chrome/browser/ui/libgtkui/gconf_listener.h
+++ b/chrome/browser/ui/libgtkui/gconf_listener.h
@@ -16,15 +16,15 @@
#include "chrome/browser/ui/libgtkui/gtk_signal.h"
namespace libgtkui {
-class Gtk2UI;
+class GtkUi;
// On GNOME desktops, subscribes to the gconf key which controlls button order.
// Everywhere else, SetTiltebarButtons() just calls back into BrowserTitlebar
// with the default ordering.
class GConfListener {
public:
- // Sends data to the Gtk2UI when available.
- explicit GConfListener(Gtk2UI* delegate);
+ // Sends data to the GtkUi when available.
+ explicit GConfListener(GtkUi* delegate);
~GConfListener();
private:
@@ -44,7 +44,7 @@ class GConfListener {
void ParseAndStoreButtonValue(GConfValue* gconf_value);
void ParseAndStoreMiddleClickValue(GConfValue* gconf_value);
- Gtk2UI* delegate_;
+ GtkUi* delegate_;
// Pointer to our gconf context. NULL if we aren't on a desktop that uses
// gconf.
« no previous file with comments | « chrome/browser/themes/theme_service.cc ('k') | chrome/browser/ui/libgtkui/gconf_listener.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698